@@ -10,13 +10,14 @@ from pythautomata.tests.test_sequence import TestSequence
 from pythautomata.tests.test_dfa_operations import TestDFAOperations
 from pythautomata.tests.test_automata_definitions import TestAutomataDefinitions
 from pythautomata.tests.test_regex_generator import TestRegexGenerator
+from pythautomata.tests.test_pdfa_metrics import TestPDFAMetrics
 
 
 def get_all_tests():
     return [TestPDFAGenerator, TestMinimizer, TestAutomataConvertor,
             TestDFAGenerators, TestAutomataComparison, TestSequence,
             TestDFAOperations, TestAutomataDefinitions, TestPDFAGenerator,
-            TestRegexGenerator, TestPDFASerialization]
+            TestRegexGenerator, TestPDFASerialization, TestPDFAMetrics]
 
 
 def run():
